/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */


var exec = require('cordova/exec');

/**
 * Navigation class
 * @constructor
 */
function Navigation() {
}

Navigation.prototype.StatusBarStyle = {
    Default: 0,
    Light: 1,
    Hidden: 2
};

var _noop = function() {};
/**
 * 控制导航栏右边按钮
 * @type {{setTitle: setTitle, setIcon: setIcon}}
 */
Navigation.prototype.rightitem = {
    setTitle: function(title, color) {
        var suc = _noop,
            err = _noop;
        if (typeof title == 'function') {
            //hdp调用，传了回调
            suc = arguments[0];
            err = arguments[1];
            title = arguments[2];
            color = arguments[3];
        }
        title = title || '';
        Navigation.prototype.rightItemTitle = title;
        exec(suc, err, "Navigation", "setRightTitle", [title, color]);
    }
};

/**Navigation.prototype.setRightTitle = function(title) {
    var suc = _noop,
        err = _noop;
        if (typeof title == 'function') {
            //hdp调用，传了回调
            suc = arguments[0];
            err = arguments[1];
            title = arguments[2];
        }
        title = title || '';
        exec(suc, err, "Navigation", "setRightTitle", [title]);
};*/
/**
 * 设置导航栏中间标题
 * @param title
 */
Navigation.prototype.setTitle = function(title, color) {
    var suc = _noop,
        err = _noop;
    if (typeof title == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        title = arguments[2];
        color = arguments[3];
    }
    title = title || '';
    exec(suc, err, "Navigation", "setTitle", [title, color]);
};

/**
 * 隐藏默认导航栏
 * @param title
 */
Navigation.prototype.hideTitle = function() {
    var suc = _noop,
        err = _noop;
    //hdp调用，传了回调
    suc = arguments[0];
    err = arguments[1];
    exec(suc, err, "Navigation", "hideTitle");
};

/**
 * 返回
 * @param title
 */
Navigation.prototype.returnClick = function() {
    var suc = _noop,
        err = _noop;
    //hdp调用，传了回调
    suc = arguments[0];
    err = arguments[1];
    exec(suc, err, "Navigation", "returnClick");
};

/**
 * 返回
 * @param title
 */
Navigation.prototype.showProgress = function() {
    var suc = _noop,
        err = _noop;
    //hdp调用，传了回调
    suc = arguments[0];
    err = arguments[1];
    exec(suc, err, "Navigation", "showProgress");
};

/**
 * 返回
 * @param title
 */
Navigation.prototype.hideProgress = function() {
    var suc = _noop,
        err = _noop;
    //hdp调用，传了回调
    suc = arguments[0];
    err = arguments[1];
    exec(suc, err, "Navigation", "hideProgress");
};

/**
 * 将一个新的页面推入视图栈
 * @param path
 */
Navigation.prototype.pushWindow = function (path) {
    var suc = _noop,
        err = _noop;
    if (typeof path == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        path = arguments[2];
    }
    exec(suc, err, "Navigation", "pushWindow", [path]);
};

/**
 * 将当前页面弹出试图栈
 * @param msg
 */
Navigation.prototype.popWindow = function (msg) {
    var suc = _noop,
        err = _noop;
    if (typeof msg == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        msg = arguments[2];
    }
    exec(suc, err, "Navigation", "popWindow", [msg || '']);
};

/**
 * 返回到根root
 * @param msg
 */
Navigation.prototype.popToRoot = function (msg) {
    var suc = _noop,
        err = _noop;
    if (typeof msg == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        msg = arguments[2];
    }
    exec(suc, err, "Navigation", "popToRoot", [msg || '']);
};

/**
 * 设置navgtaionbar背景
 */
Navigation.prototype.setNavgationBackground = function (color, alpha) {
    var suc = _noop,
        err = _noop;
    if (typeof color == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        color = arguments[2];
        alpha = arguments[3];
    }
    alpha = (typeof alpha == 'number' && alpha >= 0) ? (Math.round(alpha * 10) / 10) : 1; //取1位小数即可
    exec(suc, err, "Navigation", "setBackground", [color, alpha]);
}

/**
 * 设置statusbar的样式 （深、浅）
 * IOS Only
 */
Navigation.prototype.setStatusBarLight = function (flag) {
    var suc = _noop,
        err = _noop;
    if (typeof flag == 'function') {
        //hdp调用，传了回调
        suc = arguments[0];
        err = arguments[1];
        flag = arguments[2];
    }
    flag = flag || 0;

    if (typeof flag != 'number' || flag < 0 || flag > 2) {
        flag = 0;
    }

    exec(suc, err, "Navigation", "setStatusBarLight", [flag]);
}

module.exports = new Navigation();